@@ -20,28 +20,6 @@
 #include <klocalizedstring.h>
 
 using namespace GlossaryNS;
-// #include <QShortcutEvent>
-
-// TermLabel::TermLabel(QAction* action/*const QString& shortcutQWidget* parent,Qt::Key key,const QString& termTransl*/)
-//         : m_action(action)
-//     //: m_shortcut(shortcut)
-//    // : QLabel(/*parent*/)
-//     //, m_termTransl(termTransl)
-//     {
-// //         setFlat(true);
-// //         grabShortcut(Qt::AltModifier+Qt::ControlModifier+key);
-// //         qCWarning(LOKALIZE_LOG) << "dsds " << grabShortcut(Qt::AltModifier+key);
-//     }
-//     //~TermLabel(){}
-// // bool TermLabel::event(QEvent *event)
-// // {
-// //     if (event->type() != QEvent::Shortcut)
-// //         return QLabel::event(event);
-// //
-// // //         qCWarning(LOKALIZE_LOG) << "dsds " << m_termTransl;
-// //     Q_EMIT insertTerm(m_termTransl);
-// //     return true;
-// // }
 
 void TermLabel::insert()
 {
@@ -102,27 +80,4 @@ void TermLabel::setText(const QString &term, const QByteArray &entryId, bool cap
                 + Project::instance()->glossary()->terms(m_entryId, Project::instance()->targetLangCode()).join(n) + n));
 }
 
-#if 0
-void QueryResultBtn::insert()
-{
-//     qCWarning(LOKALIZE_LOG)<<"ins "<<text();
-    Q_EMIT insertText(m_text);
-}
-
-QueryResultBtn::QueryResultBtn(QAction* a)
-    : QLabel()
-    , m_action(a)
-{
-    setWordWrap(true);
-//     qCWarning(LOKALIZE_LOG)<<"ctor";
-    //connect(this,SIGNAL(clicked(bool)),this,SLOT(insert()));
-}
-
-void QueryResultBtn::mousePressEvent(QMouseEvent*/* event*/)
-{
-    Q_EMIT insertText(m_text);
-}
-
-#endif
-
 #include "moc_termlabel.cpp"
