@@ -4,14 +4,15 @@
   SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
   SPDX-FileCopyrightText: 2023 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+  SPDX-FileCopyrightText: 2025 Finley Watson <fin-w@tutanota.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "filesearchtab.h"
 #include "catalog.h"
+#include "config-lokalize.h"
 #include "fastsizehintitemdelegate.h"
-#include "filesearchadaptor.h"
 #include "lokalize_debug.h"
 #include "prefs.h"
 #include "project.h"
@@ -22,7 +23,6 @@
 #include <QApplication>
 #include <QBoxLayout>
 #include <QClipboard>
-#include <QDBusConnection>
 #include <QDragEnterEvent>
 #include <QElapsedTimer>
 #include <QHeaderView>
@@ -41,6 +41,7 @@
 #include <KColorScheme>
 #include <KLocalizedString>
 #include <KXMLGUIFactory>
+#include <qtmetamacros.h>
 
 QList<int> FileSearchTab::ids;
 
@@ -507,12 +508,10 @@ FileSearchTab::FileSearchTab(QWidget *parent)
         view->setColumnWidth(column, maxInitialWidths[column]);
     // END resizeColumnToContents
 
-    int i = 6;
-    while (--i > ID_STATUS_PROGRESS)
-        statusBarItems.insert(i, QString());
-
     setXMLFile(QStringLiteral("filesearchtabui.rc"), true);
+#if HAVE_DBUS
     dbusObjectPath();
+#endif
 
     KActionCollection *ac = actionCollection();
     KActionCategory *srf = new KActionCategory(i18nc("@title actions category", "Search and replace in files"), ac);
@@ -561,7 +560,6 @@ void FileSearchTab::performSearch()
     }
 
     m_model->clear();
-    statusBarItems.insert(1, QString());
     m_searchFileListView->scrollTo();
 
     m_lastSearchNumber++;
@@ -652,14 +650,15 @@ void FileSearchTab::openFile()
 
 void FileSearchTab::fileSearchNext()
 {
-    QModelIndex item = ui_fileSearchOptions->treeView->currentIndex();
-    int row = item.row();
-    int rowCount = m_model->rowCount();
+    const int currentRow = ui_fileSearchOptions->treeView->currentIndex().row();
+    const int nextRow = currentRow + 1;
+    const int rowCount = m_model->rowCount();
 
-    if (++row >= rowCount) // ok if row was -1 (no solection)
+    if (nextRow >= rowCount)
         return;
 
-    ui_fileSearchOptions->treeView->setCurrentIndex(item.sibling(row, item.column()));
+    Q_ASSERT(ui_fileSearchOptions->treeView->model() == m_model);
+    ui_fileSearchOptions->treeView->setCurrentIndex(m_model->index(nextRow));
     openFile();
 }
 
@@ -691,6 +690,11 @@ void FileSearchTab::setTargetQuery(const QString &query)
     ui_fileSearchOptions->queryTarget->setText(query);
 }
 
+void FileSearchTab::updateStatusBarContents()
+{
+    Q_EMIT signalStatusBarTotal(m_model->rowCount());
+}
+
 void FileSearchTab::searchJobDone(SearchJob *j)
 {
     j->deleteLater();
@@ -703,7 +707,7 @@ void FileSearchTab::searchJobDone(SearchJob *j)
         m_searchFileListView->scrollTo(j->results.last().filepath);
     }
 
-    statusBarItems.insert(1, i18nc("@info:status message entries", "Total: %1", m_model->rowCount()));
+    Q_EMIT signalStatusBarTotal(m_model->rowCount());
 }
 
 void FileSearchTab::replaceJobDone(MassReplaceJob *j)
@@ -794,6 +798,10 @@ void MassReplaceView::deactivatePreview()
 }
 
 // BEGIN DBus interface
+#if HAVE_DBUS
+#include "filesearchadaptor.h"
+#include <QDBusConnection>
+
 QString FileSearchTab::dbusObjectPath()
 {
     QString FILESEARCH_PATH = QStringLiteral("/ThisIsWhatYouWant/FileSearch/");
@@ -810,6 +818,7 @@ QString FileSearchTab::dbusObjectPath()
 
     return FILESEARCH_PATH + QString::number(m_dbusId);
 }
+#endif
 
 bool FileSearchTab::findGuiTextPackage(QString text, [[maybe_unused]] QString package)
 {
