@@ -5,8 +5,6 @@
 */
 
 #include "languagetoolgrammarerror.h"
-#include "languagetoolmanager.h"
-#include "lokalize_debug.h"
 
 #include <klocalizedstring.h>
 
@@ -18,19 +16,6 @@ QString LanguageToolGrammarError::parse(const QJsonObject &obj, const QString &t
     int mStart = obj[QStringLiteral("offset")].toInt(-1);
     int mLength = obj[QStringLiteral("length")].toInt(-1);
     QStringList mSuggestions = parseSuggestion(obj);
-    /*
-    const QJsonObject rulesObj = obj[QStringLiteral("rule")].toObject();
-    if (!rulesObj.isEmpty()) {
-        QString mRule = rulesObj[QStringLiteral("id")].toString();
-        const QJsonArray urlArray = rulesObj[QStringLiteral("urls")].toArray();
-        if (!urlArray.isEmpty()) {
-            if (urlArray.count() > 1) {
-                qCWarning(LOKALIZE_LOG) << "LanguageToolGrammarError::parse : more than 1 url found. Perhaps need to adapt api ";
-            }
-            QString mUrl = urlArray.at(0)[QLatin1String("value")].toString();
-            //qDebug() << " mUrl" << mUrl;
-        }
-    }*/
     QString result = mError;
     if (mLength > 0)
         result = result + QStringLiteral(" (") + text.mid(mStart, mLength) + QStringLiteral(")");
@@ -54,6 +39,5 @@ QStringList LanguageToolGrammarError::parseSuggestion(const QJsonObject &obj)
             lst.append(suggestionObject[QLatin1String("value")].toString());
         }
     }
-    // qDebug() << " lst : " << lst;
     return lst;
 }
