@@ -3,6 +3,7 @@
 
   SPDX-FileCopyrightText: 2007-2014 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2025 Finley Watson <fin-w@tutanota.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -11,6 +12,7 @@
 
 #include "lokalize_debug.h"
 
+#include "config-lokalize.h"
 #include "dbfilesmodel.h"
 #include "fastsizehintitemdelegate.h"
 #include "jobs.h"
@@ -41,6 +43,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KXMLGUIFactory>
+#include <qtmetamacros.h>
 
 #if defined(Q_OS_WIN) && defined(QStringLiteral)
 #undef QStringLiteral
@@ -464,22 +467,19 @@ TMTab::TMTab(QWidget *parent)
     int column = sizeof(maxInitialWidths) / sizeof(int);
     while (--column >= 0)
         view->setColumnWidth(column, maxInitialWidths[column]);
-
     // END resizeColumnToContents
 
-    int i = 6;
-    while (--i > ID_STATUS_PROGRESS)
-        statusBarItems.insert(i, QString());
-
     setXMLFile(QStringLiteral("translationmemoryrui.rc"), true);
     setUpdatedXMLFile();
+#if HAVE_DBUS
     dbusObjectPath();
+#endif
 
     QAction *action;
     KActionCollection *ac = actionCollection();
     KActionCategory *tm = new KActionCategory(i18nc("@title actions category", "Translation Memory"), ac);
 
-    action = tm->addAction(QStringLiteral("tools_tm_manage"), Project::instance(), SLOT(showTMManager()));
+    action = tm->addAction(QStringLiteral("tools_tm_manage"), Project::instance(), &Project::showTMManager);
     action->setText(i18nc("@action:inmenu", "Manage translation memories"));
 
     m_qaView = new QaView(this);
@@ -508,7 +508,11 @@ TMTab::~TMTab()
 
 void TMTab::updateTM()
 {
-    if (Project::instance()->isLoaded()) {
+    if (!Project::instance()->isLoaded()) {
+        KMessageBox::information(this,
+                                 i18n("Rescanning files is only possible while a project is open. Please open a project and try again."),
+                                 i18n("Rescan not possible"));
+    } else {
         scanRecursive(QStringList(Project::instance()->poDir()), Project::instance()->projectID());
         if (Settings::deleteFromTMOnMissing()) {
             RemoveMissingFilesJob *job = new RemoveMissingFilesJob(Project::instance()->projectID());
@@ -580,9 +584,9 @@ void TMTab::displayTotalResultCount()
     int total = m_model->totalResultCount();
     int filtered = m_proxyModel->rowCount();
     if (filtered == m_model->rowCount())
-        statusBarItems.insert(1, i18nc("@info:status message entries", "Total: %1", total));
+        Q_EMIT signalStatusBarTotal(total);
     else
-        statusBarItems.insert(1, i18nc("@info:status message entries", "Total: %1 (%2)", filtered, total));
+        Q_EMIT signalStatusBarTotal(filtered);
     m_model->m_dbOperationMutex.unlock();
 }
 
@@ -654,9 +658,10 @@ void TMTab::dropEvent(QDropEvent *event)
         event->acceptProposedAction();
 }
 
+QList<int> TMTab::ids;
+#if HAVE_DBUS
 #include "translationmemoryadaptor.h"
 // BEGIN DBus interface
-QList<int> TMTab::ids;
 
 QString TMTab::dbusObjectPath()
 {
@@ -674,6 +679,7 @@ QString TMTab::dbusObjectPath()
 
     return TM_PATH + QString::number(m_dbusId);
 }
+#endif
 
 void TMTab::lookup(QString source, QString target)
 {
