@@ -184,7 +184,7 @@ void DynamicItemHeightQListWidget::updateListItemHeights()
 
 TMView::TMView(QWidget *parent, Catalog *catalog, const QVector<QAction *> &actions_insert, const QVector<QAction *> &actions_remove)
     : QDockWidget(i18nc("@title:window", "Translation Memory"), parent)
-    , m_tm_entries_list(new DynamicItemHeightQListWidget(this))
+    , m_entriesList(new DynamicItemHeightQListWidget(this))
     , m_catalog(catalog)
     , m_actions_insert(actions_insert)
     , m_actions_remove(actions_remove)
@@ -192,7 +192,7 @@ TMView::TMView(QWidget *parent, Catalog *catalog, const QVector<QAction *> &acti
     , m_hasInfoTitle(m_normTitle + QStringLiteral(" [*]"))
 {
     setObjectName(QStringLiteral("TMView"));
-    setWidget(m_tm_entries_list);
+    setWidget(m_entriesList);
 
     QTimer::singleShot(0, this, &TMView::initLater);
     connect(m_catalog, qOverload<const QString &>(&Catalog::signalFileLoaded), this, &TMView::slotFileLoaded);
@@ -312,7 +312,6 @@ void TMView::slotBatchSelectDone()
             bool forceFuzzy = (suggList.size() > 1 && suggList.at(1).score >= 10000) || entry.score < 10000;
             bool ctxtMatches = entry.score == 1001;
             if (!m_catalog->isApproved(pos.entry)) {
-                /// m_catalog->push(new DelTextCmd(m_catalog,pos,m_catalog->msgstr(pos)));
                 removeTargetSubstring(m_catalog, pos, 0, m_catalog->targetWithTags(pos).string.size());
                 insertCatalogString(m_catalog, pos, entry.target, 0);
                 if (ctxtMatches || !(m_markAsFuzzy || forceFuzzy))
@@ -323,7 +322,6 @@ void TMView::slotBatchSelectDone()
             } else {
                 insertCatalogString(m_catalog, pos, entry.target, 0);
             }
-            /// m_catalog->push(new InsTextCmd(m_catalog,pos,entry.target));
 
             if (Q_UNLIKELY(m_pos.entry == pos.entry && pos.form == m_pos.form))
                 Q_EMIT refreshRequested();
@@ -392,13 +390,9 @@ void TMView::slotNewEntryDisplayed(const DocPosition &pos)
         [[maybe_unused]] const bool result = TM::threadPool()->tryTake(job);
     }
 
-    // update DB
-    // m_catalog->flushUpdateDBBuffer();
-    // this is called via subscribtion
-
     if (pos.entry != -1)
         m_pos = pos;
-    m_tm_entries_list->clear();
+    m_entriesList->clear();
     if (Settings::prefetchTM() && m_cache.contains(DocPos(m_pos))) {
         QTimer::singleShot(0, this, &TMView::displayFromCache);
     }
@@ -420,7 +414,7 @@ void TMView::displayFromCache()
 void TMView::showEvent(QShowEvent *event)
 {
     if (event->type() == QShowEvent::Show)
-        m_tm_entries_list->updateListItemHeights();
+        m_entriesList->updateListItemHeights();
     QWidget::showEvent(event);
 }
 
@@ -482,8 +476,8 @@ void TMView::slotSuggestionsCame(SelectJob *j)
     }
 
     setUpdatesEnabled(false);
-    m_tm_entries_list->viewport()->setUpdatesEnabled(false);
-    m_tm_entries_list->clear();
+    m_entriesList->viewport()->setUpdatesEnabled(false);
+    m_entriesList->clear();
     int i = 0;
     QString keyboardShortcut;
     QString occurrences;
@@ -555,8 +549,8 @@ void TMView::slotSuggestionsCame(SelectJob *j)
                                                                                                 "<li>%3</li>"
                                                                                                 "</ul>")
                                                                                      .arg(metadata, source, target));
-        m_tm_entries_list->addItem(translationMemoryEntryItem);
-        m_tm_entries_list->setItemWidget(translationMemoryEntryItem, label);
+        m_entriesList->addItem(translationMemoryEntryItem);
+        m_entriesList->setItemWidget(translationMemoryEntryItem, label);
         // Double-clicking words in a TM entry should add the selected
         // word to the current translation target at the cursor position.
         connect(label, &DoubleClickToInsertTextQLabel::textInsertRequested, this, &TMView::textInsertRequested);
@@ -566,8 +560,8 @@ void TMView::slotSuggestionsCame(SelectJob *j)
         if (Q_UNLIKELY(++i >= limit))
             break;
     }
-    m_tm_entries_list->updateListItemHeights();
-    m_tm_entries_list->viewport()->setUpdatesEnabled(true);
+    m_entriesList->updateListItemHeights();
+    m_entriesList->viewport()->setUpdatesEnabled(true);
     setUpdatesEnabled(true);
 }
 
@@ -575,8 +569,8 @@ bool TMView::event(QEvent *event)
 {
     if (event->type() == QEvent::ToolTip) {
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
-        for (int i = 0; i < m_tm_entries_list->count(); ++i) {
-            if (m_tm_entries_list->itemWidget(m_tm_entries_list->item(i))->underMouse()) {
+        for (int i = 0; i < m_entriesList->count(); ++i) {
+            if (m_entriesList->itemWidget(m_entriesList->item(i))->underMouse()) {
                 const TMEntry &tmEntry = m_entries.at(i);
                 QString file = tmEntry.file;
                 if (file == m_catalog->url())
@@ -593,8 +587,8 @@ bool TMView::event(QEvent *event)
                 return true;
             }
         }
-    } else if (event->type() == QEvent::Resize && m_tm_entries_list->count() > 0) {
-        m_tm_entries_list->updateListItemHeights();
+    } else if (event->type() == QEvent::Resize && m_entriesList->count() > 0) {
+        m_entriesList->updateListItemHeights();
     }
     return QDockWidget::event(event);
 }
@@ -641,8 +635,8 @@ void TMView::runJobs()
 
 void TMView::contextMenu(const QPoint &pos)
 {
-    for (int i = 0; i < m_tm_entries_list->count(); ++i) {
-        QWidget *entry = m_tm_entries_list->itemWidget(m_tm_entries_list->item(i));
+    for (int i = 0; i < m_entriesList->count(); ++i) {
+        QWidget *entry = m_entriesList->itemWidget(m_entriesList->item(i));
         if (entry->underMouse()) {
             const TMEntry *tmEntry = &m_entries.at(i);
             enum {
@@ -703,10 +697,8 @@ static int nextPlacableIn(const QString &old, int start, QString &cap)
     static const QRegularExpression rxAbbr(QStringLiteral("\\w+"), QRegularExpression::UseUnicodePropertiesOption);
 
     const auto numMatch = rxNum.match(old, start);
-    //    int abbrPos=rxAbbr.indexIn(old,start);
     QRegularExpressionMatch abbrMatch;
     int abbrPos = start;
-    // qCWarning(LOKALIZE_LOG)<<"seeing"<<old.size()<<old;
     while (true) {
         abbrMatch = rxAbbr.match(old, abbrPos);
         if (!abbrMatch.hasMatch()) {
@@ -729,13 +721,7 @@ static int nextPlacableIn(const QString &old, int start, QString &cap)
     if (pos == -1)
         pos = qMax(numMatch.capturedStart(), abbrPos);
 
-    //     if (pos==numMatch.capturedStart())
-    //         cap=numMatch.captured(0);
-    //     else
-    //         cap=rxAbbr.cap(0);
-
     cap = pos == numMatch.capturedStart() ? numMatch.captured(0) : abbrMatch.captured(0);
-    // qCWarning(LOKALIZE_LOG)<<cap;
 
     return pos;
 }
@@ -970,14 +956,6 @@ void TMView::slotUseSuggestion(int i)
 
     CatalogString target = targetAdapted(m_entries.at(i), m_catalog->sourceWithTags(m_pos));
 
-#if 0
-    QString tmp = target.string;
-    tmp.replace(TAGRANGE_IMAGE_SYMBOL, '*');
-    qCWarning(LOKALIZE_LOG) << "targetAdapted" << tmp;
-
-    foreach (InlineTag tag, target.tags)
-        qCWarning(LOKALIZE_LOG) << "tag" << tag.start << tag.end;
-#endif
     if (Q_UNLIKELY(target.isEmpty()))
         return;
 
@@ -988,11 +966,9 @@ void TMView::slotUseSuggestion(int i)
         m_pos.offset = 0;
         // FIXME test!
         removeTargetSubstring(m_catalog, m_pos, 0, old.size());
-        // m_catalog->push(new DelTextCmd(m_catalog,m_pos,m_catalog->msgstr(m_pos)));
     }
     qCWarning(LOKALIZE_LOG) << "1" << target.string;
 
-    // m_catalog->push(new InsTextCmd(m_catalog,m_pos,target)/*,true*/);
     insertCatalogString(m_catalog, m_pos, target, 0);
 
     if (m_entries.at(i).score > 9900 && !m_catalog->isApproved(m_pos.entry))
